@@ -31,11 +31,15 @@ from threadpool import *
 
 # BigJob/Pilot framework classes
 from bigjob import logger
-from pilot.impl.pilotdata_manager import PilotData, DataUnit, PilotDataService
+
+try:
+    from pilot.impl.pilotdata_manager import PilotData, DataUnit, PilotDataService
+except:
+    logger.warning("Pilot Data classes could not be loaded. File movement will not work!")
 
 logger.debug("Python Version: " + str(sys.version_info))
 if sys.version_info < (2, 5):
-    sys.stderr.write("Warning: Using unsupported Python version\n")
+    sys.stderr.write("Python 2.4 - Warning: Not all functionalities working\n")
 if sys.version_info < (2, 4):
     sys.stderr.write("Warning: Using unsupported Python version\n")
 if sys.version_info < (2, 3):
