@@ -45,7 +45,13 @@ class GlobusOnlineFileAdaptor(object):
         
         # initialize ssh client
         self.__state=State.New
-                        
+
+
+    def get_security_context(self):
+        """ Returns security context that needs to be available on the distributed
+            node in order to access this Pilot Data """
+        return None
+    
         
     def initialize_pilotdata(self):
         # check whether directory exists
