@@ -37,7 +37,7 @@ from pilot.coordination.redis_adaptor import RedisCoordinationAdaptor as Coordin
 from pilot.scheduler.data_compute_affinity_scheduler import Scheduler
 
 class ComputeDataService(ComputeDataService):
-    """ B{ComputeDataService}
+    """ B{ComputeDataService (CDS).}
     
         The ComputeDataService is the application's interface to submit 
         ComputeUnits and PilotData/DataUnit to the Pilot-Manager 
@@ -121,6 +121,9 @@ class ComputeDataService(ComputeDataService):
         CoordinationAdaptor.update_cds(self.url, self)
         return cu
     
+    def list_pilot_compute(self):
+        """ List all pilot compute of CDS """
+        return self.pilot_job_service
     
     ###########################################################################
     # Pilot Data     
@@ -139,12 +142,7 @@ class ComputeDataService(ComputeDataService):
         self.pilot_data_services.remove(pds)
         CoordinationAdaptor.update_cds(self.url, self)
     
-    
-    def list_pilot_compute(self):
-        """ List all pilot compute of CDS """
-        return self.pilot_job_service
-    
-    
+     
     def list_pilot_data(self):
         """ List all pilot data of CDS """
         return self.pilot_data_services
@@ -261,7 +259,7 @@ class ComputeDataService(ComputeDataService):
                         logger.debug("Initiate Transfer to PD.")
                         du.add_pilot_data(pd)
                         logger.debug("Transfer to PD finished.")
-                        du.update_state(State.Running) 
+                        du._update_state(State.Running) 
                         self.du_queue.task_done()                   
                     else:
                         self.du_queue.task_done() 
